@@ -6,11 +6,12 @@ Last update: 2022.11.15
 """
 import os
 import math
-import sys
 import collections
+import shutil
 from excelParse import ParserXLS, FastqToFC
 
 
+
 def ding_talk(msn, mobiles, access_token = 'e20f01ecb7d4cb1c78975d0946667f934092043c4d11e855a397bf4ad1a84ef1'):
     talk = """curl 'https://oapi.dingtalk.com/robot/send?access_token=%s' \
 -H 'Content-Type: application/json' -d '{"msgtype": "text","text": {"content":"%s"},"at":{"atMobiles":%s}}'
@@ -125,7 +126,7 @@ class Geo_common:
             fail_talk = ding_talk(fail_msn, self.analyst_phone_number)
             with open(shell,'w') as f:
                 f.write("""
-snakemake --cluster-config %s/pipeline.yaml --cluster "sbatch -c {cluster.c} -o {cluster.o} -e {cluster.e} --parsable " --cluster-cancel scancel --use-singularity --singularity-args "%s" -j 20 -ps %s/master_%s.smk --configfile %s --directory %s --latency-wait 300 
+snakemake --cluster-config %s/pipeline.yaml --cluster "sbatch -c {cluster.c} -o {cluster.o} -e {cluster.e} --parsable " --cluster-cancel scancel --use-singularity --singularity-args "%s" -j 20 -ps %s/master/master_%s.smk --configfile %s --directory %s --latency-wait 300 
 
 if [ $? -eq 0 ];
 then
@@ -182,3 +183,7 @@ fi
         # 打印运行命令
         msn = "\n\033[34m%s\033[0m 的shell脚本已生成。shell脚本路径为: \033[34m%s\033[0m .\n\n您可以选择运行以下命令：\n%s"%(self.contract_number, self.pro_dir , "\n".join(shells))
         print(msn)
+
+    def copy_mkdir(self):
+        os.system("mkdir -p %s/log/slurmlog" %(self.pro_dir))
+        shutil.copy(os.path.join(self.pipe_dir,"pipeline.yaml"),self.pro_dir)
\ No newline at end of file
